@@ -18,7 +18,7 @@ Generic duplicate document chain.
 """
 
 import flask
-from manhattan.assets.fields import AssetField
+from manhattan.assets.fields import AssetField, ImageSetField
 from manhattan.chains import Chain, ChainMgr
 from manhattan.nav import Nav, NavItem
 
@@ -157,7 +157,16 @@ def duplicate_document(state):
     """
 
     # Initialize a new duplicate document
-    dup_document = state.manage_config.frame_cls(**state.form_data)
+    dup_document = state.manage_config.frame_cls()
+
+    # Populate the document from the form
+    for k, v in state.form_data.items():
+
+        if k in state.form \
+                and isinstance(state.form[k], (AssetField, ImageSetField)):
+            continue
+
+        setattr(dup_document, k, v)
 
     # Insert the document
     dup_document.logged_insert(state.manage_user)
