@@ -21,7 +21,7 @@ Generic update document chain.
 """
 
 import flask
-from manhattan.assets.fields import AssetField
+from manhattan.assets.fields import AssetField, ImageSetField
 from manhattan.chains import Chain, ChainMgr
 from manhattan.nav import Nav, NavItem
 
@@ -145,7 +145,8 @@ def update_document(state):
     form_data = {}
     for k, v in state.form_data.items():
 
-        if k in state.form and isinstance(state.form[k], AssetField):
+        if k in state.form \
+                and isinstance(state.form[k], (AssetField, ImageSetField)):
             continue
 
         form_data[k] = v
